pub struct CheckpointManager { /* private fields */ }Expand description
Manages checkpoints for agent crash recovery.
Implementations
Sourceimpl CheckpointManager
impl CheckpointManager
Sourcepub fn default_dir() -> Result<Self>
pub fn default_dir() -> Result<Self>
Create a default checkpoint manager (~/.ares/checkpoints/).
Sourcepub fn save(&self, checkpoint: &Checkpoint) -> Result<()>
pub fn save(&self, checkpoint: &Checkpoint) -> Result<()>
Save a checkpoint to disk.
Sourcepub fn load_latest(&self, session_id: &str) -> Result<Option<Checkpoint>>
pub fn load_latest(&self, session_id: &str) -> Result<Option<Checkpoint>>
Load the latest checkpoint for a session.
Sourcepub fn list_checkpoints(&self, session_id: &str) -> Result<Vec<Checkpoint>>
pub fn list_checkpoints(&self, session_id: &str) -> Result<Vec<Checkpoint>>
List all checkpoints for a session, ordered by step.
Sourcepub fn cleanup(&self, session_id: &str) -> Result<usize>
pub fn cleanup(&self, session_id: &str) -> Result<usize>
Clean up old checkpoints for a completed session.
Sourcepub fn cleanup_expired(&self, now: u64) -> Result<usize>
pub fn cleanup_expired(&self, now: u64) -> Result<usize>
Remove checkpoint files whose metadata has expired relative to now.
Sourcepub fn has_checkpoint(&self, session_id: &str) -> bool
pub fn has_checkpoint(&self, session_id: &str) -> bool
Check if a session has a recoverable checkpoint.