pub fn detect_loop(
config: &LoopConfig,
state: &LoopState,
output: &str,
) -> Option<LoopDetection>Expand description
Detect a repetitive output against recent window state (does not mutate state).
pub fn detect_loop(
config: &LoopConfig,
state: &LoopState,
output: &str,
) -> Option<LoopDetection>Detect a repetitive output against recent window state (does not mutate state).